@@ -34,9 +34,7 @@ class Grabber(pyd.BaseModel, extra="forbid", copy_on_model_validation="none"):
         return_type: ReturnType = ReturnType.SAMPLE,
         size: t.Optional[int] = None,
         *,
-        worker_init_fn: t.Union[
-            t.Callable, t.Tuple[t.Callable, t.Sequence], None
-        ] = None,
+        worker_init_fn: t.Optional[t.Tuple[t.Callable, t.Sequence]] = None,
     ) -> _GrabContext:
         return _GrabContext(
             self,
@@ -68,21 +66,30 @@ class _GrabContext:
         sequence: pls.SamplesSequence,
         return_type: ReturnType,
         size: t.Optional[int],
-        worker_init_fn: t.Union[t.Callable, t.Tuple[t.Callable, t.Sequence], None],
+        worker_init_fn: t.Optional[t.Tuple[t.Callable, t.Sequence]],
     ):
         self._grabber = grabber
         self._sequence = sequence
         self._return_type = return_type
         self._size = size
         self._pool = None
-        self._worker_init_fn = (
-            worker_init_fn
-            if isinstance(worker_init_fn, tuple)
-            else (worker_init_fn, ())
-        )
+        self._worker_init_fn = (None, ()) if worker_init_fn is None else worker_init_fn
+
+    @staticmethod
+    def wrk_init(extra_modules, user_init_fn):
+        from pipelime.cli.utils import PipelimeSymbolsHelper
+
+        PipelimeSymbolsHelper.set_extra_modules(extra_modules)
+        PipelimeSymbolsHelper.import_everything()
+
+        if user_init_fn[0] is not None:
+            user_init_fn[0](*user_init_fn[1])
 
     def __enter__(self):
+        from pipelime.cli.utils import PipelimeSymbolsHelper
+
         if self._grabber.num_workers == 0:
+            # SINGLE PROCESS
             self._pool = None
             it = iter(self._sequence)
             if self._worker_init_fn[0] is not None:
@@ -91,10 +98,11 @@ class _GrabContext:
                 return enumerate(it)
             return it
 
+        # MULTIPLE PROCESSES
         self._pool = multiprocessing.Pool(
             self._grabber.num_workers if self._grabber.num_workers > 0 else None,
-            initializer=self._worker_init_fn[0],
-            initargs=self._worker_init_fn[1],
+            initializer=_GrabContext.wrk_init,
+            initargs=(PipelimeSymbolsHelper.extra_modules, self._worker_init_fn),
         )
         runner = self._pool.__enter__()
 
@@ -156,6 +164,18 @@ def grab_all(
     if grab_context_manager is None:
         grab_context_manager = contextlib.nullcontext()
 
+    if isinstance(worker_init_fn, t.Sequence):
+        if len(worker_init_fn) == 1:
+            worker_init_fn = (worker_init_fn[0], ())
+        elif len(worker_init_fn) != 2:
+            raise ValueError(
+                "The worker_init_fn argument must be a callable or a tuple of "
+                "a callable and its arguments."
+            )
+        worker_init_fn = tuple(worker_init_fn)
+    elif worker_init_fn is not None:
+        worker_init_fn = (worker_init_fn, ())
+
     with grab_context_manager:
         ctx = grabber(
             sequence,
